#
# spec file for package libKF5NetworkManagerQt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 6
%define _tar_path 5.55
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           libKF5NetworkManagerQt
Version:        5.55.0
Release:        lp151.1.1
Summary:        A Qt wrapper for NetworkManager DBus API
License:        LGPL-2.1-only OR LGPL-3.0-only
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/networkmanager-qt-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE
Patch0:         0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch
# PATCH-FIX-OPENSUSE
Patch1:         0001-Revert-Add-missing-ipv4-setting-options.patch
# PATCH-FIX-OPENSUSE
Patch2:         0001-Revert-Add-IpTunnel-setting.patch
# PATCH-FIX-OPENSUSE
Patch3:         0001-Revert-Add-vxlan-setting.patch
# PATCH-FIX-OPENSUSE
Patch4:         0001-Revert-Add-missing-IPv6-options.patch
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Core) >= 5.6.0
BuildRequires:  cmake(Qt5DBus) >= 5.6.0
BuildRequires:  cmake(Qt5Network) >= 5.6.0
BuildRequires:  pkgconfig(libnm) >= 1.0.0

%description
NetworkManagerQt provides access to all NetworkManager features
exposed on DBus. It allows you to manage your connections and control
your network devices and also provides a library for parsing connection
settings which are used in DBus communication.

%package devel
Summary:        A Qt wrapper for NetworkManager DBus API
Group:          Development/Libraries/KDE
Requires:       libKF5NetworkManagerQt%{soversion} = %{version}
Requires:       cmake(Qt5Core) >= 5.6.0
Requires:       cmake(Qt5DBus) >= 5.6.0
Requires:       cmake(Qt5Network) >= 5.6.0
Requires:       pkgconfig(libnm) >= 1.0.0

%description devel
NetworkManagerQt provides access to all NetworkManager features
exposed on DBus. It allows you to manage your connections and control
your network devices and also provides a library for parsing connection
settings which are used in DBus communication. Development files.

%package -n libKF5NetworkManagerQt%{soversion}
Summary:        A Qt wrapper for NetworkManager DBus API
Group:          Development/Libraries/KDE

%description -n libKF5NetworkManagerQt%{soversion}
NetworkManagerQt provides access to all NetworkManager features
exposed on DBus. It allows you to manage your connections and control
your network devices and also provides a library for parsing connection
settings which are used in DBus communication.

%prep
%setup -q -n networkmanager-qt-%{version}
%if 0%{?suse_version} < 1500
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%endif
%if 0%{?suse_version} == 1500
sed -i -e "s/^set *(REQUIRED_QT_VERSION 5.10.0)$/set(REQUIRED_QT_VERSION 5.9.0)/" CMakeLists.txt
%endif

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

%post -n libKF5NetworkManagerQt%{soversion} -p /sbin/ldconfig
%postun -n libKF5NetworkManagerQt%{soversion} -p /sbin/ldconfig

%files -n libKF5NetworkManagerQt%{soversion}
%license COPYING*
%{_kf5_libdir}/libKF5NetworkManagerQt.so.*
%{_kf5_debugdir}/networkmanager-qt.categories

%files devel
%license COPYING*
%{_kf5_libdir}/libKF5NetworkManagerQt.so
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5NetworkManagerQt/
%{_kf5_mkspecsdir}/qt_NetworkManagerQt.pri

%changelog
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * No code changes since 5.54.0
* Mon Jan 14 2019 wbauer@tmo.at
- Refresh patches to fix build on Leap 42.3:
  * 0001-Revert-Add-IpTunnel-setting.patch
  * 0001-Revert-Add-missing-IPv6-options.patch
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-vxlan-setting.patch
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * [proxysetting] Fix build with NM 1.4
  * Added DCB settings
  * A minor typo in ipv4 test
  * A minor bug in ipv4 and ipv6 test
  * macsec setting
  * TeamPortSetting: fix argument
  * team-port setting
  * match and tc setting
  * Add missing defines
  * ovs-patch and ovs-port setting
- Dropped patches, now upstream:
  * Add-missing-defines.patch
  * fix-build-with-NM-1.4.patch
* Wed Dec 12 2018 wbauer@tmo.at
- Refresh patches:
  * 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-vxlan-setting.patch
- Add some more patches to fix build with older NetworkManager
  versions (as in Leap 42.3 in particular):
  * 0001-Revert-Add-IpTunnel-setting.patch
  * 0001-Revert-Add-missing-IPv6-options.patch
  * Add-missing-defines.patch
  * fix-build-with-NM-1.4.patch
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Get rid of some unneeded defines
  * Fixed a bug(error?) in ipv4 & ipv6 settings
  * Add missing defines
  * Add ovs-bridge and ovs-interface setting
  * Update Ip-tunnel settings
  * Add proxy and user setting
  * Add IpTunnel setting
  * We can now build tun setting test all the time
  * Add missing IPv6 options
  * Listen for added DBus interfaces instead of registered services (kde#400359)
  * Remove qt include prefix
  * normalize signal/slot
* Mon Nov 12 2018 wbauer@tmo.at
- Add patches that remove some new settings on Leap 42.3 (that
  would require a newer NetworkManager) to fix the build:
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-vxlan-setting.patch
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variable
  * Add missing ipv4 setting options
  * Add vxlan setting
  * Create own categories file
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * More nullptr usage
  * Use matching enum value AuthEapMethodUnknown to compare a AuthEapMethod
  * Fix minor EBN issues
* Fri Sep 14 2018 Wolfgang Bauer <wbauer@tmo.at>
- Add 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch to
  make it build on Leap 42.3 which only has NetworkManager 1.0.
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Remove notes from API documentation about older NM versions
  * Require NetworkManager 1.4.0 and newer
  * manager: add support to R/W the GlobalDnsConfiguration property
  * Actually allow to set the refresh rate for device statistics
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * None
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove QT definitions duplicated from KDEFrameworkCompilerSettings or dead
* Wed Jun 27 2018 bjorn.lie@gmail.com
- Align with what cmake looks for:
  * Drop pkgconfig(NetworkManager), pkgconfig(libnm-glib) and
    pkgconfig(libnm-util) BuildRequires and Requires.
  * Add pkgconfig(libnm) BuildRequires and Requires.
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Add missing override
  * Use override
  * Make information about unhandled property just debug messages
  * WirelessSetting: implement assignedMacAddress property
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * None
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Export the NetworkManager include dirs.
  * Start requiring NM 1.0.0
  * We depend against 5.8.0
  * We use qt5.8.0
  * device: define StateChangeReason and MeteredStatus as Q_ENUMs
  * Fix conversion of AccessPoint flags to capabilities
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove not necessary virtual keyword
  * 802-11-x: support for PWD EAP method
  * it was split
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Remove redundant map look-ups
  * Don't do unnecessary QString allocations to convert parts of it into strings
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix 8021xSetting unit test
  * 8021xSetting: domain-suffix-match is defined in NM 1.2.0 and newer
  * Support "domain-suffix-match" in Security8021xSetting
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * None
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Adding support to ipv*.route-metric
  * Fix undefined NM_SETTING_WIRELESS_POWERSAVE_FOO enums (kde#382051)
  * Add .arcconfig
- Drop Fix-undefined-enums.patch (merged upstream)
* Wed Jul 12 2017 wbauer@tmo.at
- Add Fix-undefined-enums.patch to make it build with NM 1.0.x on
  Leap 42 (kde#382051)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Too many changes to list here
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * None
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix crash when retrieving active connection list. (kde#373993)
  * -Wheader-guard
  * -Wheader-guard
  * Fix unit test
  * Set default value for auto-negotiation based on running NM version
  * One more attempt to fix unit test for active connections
  * Fix unit test for active connections
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * WiredSetting: return autonegotiate even when it's disabled
  * Prevent signals in glib2 be defined by Qt
  * prevent signals in glib2 be defined by Qt
  * WiredSetting: Speed and duplex can be set only when auto-negotiation is off
  * Auto-negotiate value for wired setting should be false
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Sync introspections and generated files with NM 1.6.0
  * Manager: Fix emitting deviceAdded twice when NM restarts
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Wed Nov 16 2016 hrvoje.senjan@gmail.com
- Raise (Build)Required NM version to 0.9.10.0 (as per CMakeLists.txt)
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Fix include dir in pri file
  * Fix moc error due to Q_ENUMS being used in a namespace,
    with Qt branch 5.8
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * We need to set the state during initialization
  * Replace all blocking calls for initialization with
    just one blocking call
  * Use standard o.f.DBus.Properties interface for PropertiesChanged
    signal for NM 1.4.0+ (kde#367938)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop upstreamed fix-icons-with-NM-1.4.0.patch
* Sun Sep 25 2016 wbauer@tmo.at
- Add fix-icons-with-NM-1.4.0.patch to work around a bug in
  NetworkManager 1.4.0 that causes wrong status icons (kde#367938)
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Default to WPA2-PSK and WPA2-EAP when getting security
    type from connection settings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Sun Jul 10 2016 hrvoje.senjan@gmail.com
- Raise NM BuildRequires to 0.9.10.0 so it matches reality
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Do not set peap label based on peap version
  * Make network manager version checks in runtime
    (to avoid compile vs. run-time (kde#362736))
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Revert "drop WiMAX support for NM 1.2.0+" as it breaks ABI
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * ConnectionSettings: Initialize gateway ping timeout
  * New TunSetting and Tun connection type
  * Create devices for all known types
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Re-check connection state and other properties to be sure
    they are actual (version 2) (kde#352326)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Make it work with older NM versions
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
- Drop upstreamed 0001-make-it-work-with-older-NM-versions.patch
* Wed Dec 16 2015 alarrosa@suse.com
- Added 0001-make-it-work-with-older-NM-versions.patch committed also
  upstream. This adds some #ifdefs around code that needs NM 0.9.10
  so it also builds with NM 0.9.8
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Fix introspections, LastSeen should be in AccessPoint and
    not in ActiveConnection
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Added new properties from the latest NM snapshot/releases
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Drop WiMAX support for NM 1.2.0+
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * The installed headers are now organized like all other frameworks
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- NetworkManager is a public dep, so add the correct requires to
  devel package (pkgconfig(NetworkManager), pkgconfig(libnm-glib)
  and pkgconfig(libnm-util))
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Add new properties and methods from NetworkManager 1.0.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Do not print a message about unhandled "AccessPoints" property
  * Added support for NetworkManager 1.0.0 (not required)
  * Fixed VpnSetting secrets handling
  * Added class GenericSetting for connections not managed by
    NetworkManager
  * Added property AutoconnectPriority to ConnectionSettings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
- Drop vpn.patch, merged upstream
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Added vpn.patch from upstream
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Libary is now officially a part of KDE Frameworks 5 libraries
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
- Update summary and descriptions
- Be more explicit about BuildRequires (using pkgconfig, etc)
- Added baselibs.conf
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Do not notify about changed VpnState twice
  * Watch for changes when constructing new ModemDevice
  * Add workaround to properly update IpInterface
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Mnor bugfixes since previous release
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.92
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Version update to 5.0.91
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Activate libKF5NetworkManagerQt package
